@@ -5,7 +5,6 @@ from munin_plugins.etc.env import MINUTES
 
 from base import BaseCounter
 
-
 class BotsCounter(BaseCounter):
   id='botscounter'
   base_title="Nginx Bots"
@@ -22,13 +21,13 @@ class BotsCounter(BaseCounter):
         agent=get_short_agent(agent)
         self.counter[agent]=1+self.counter[agent]
       
-  def print_data(self, printer):
+  def print_data(self, printer, w=10,c=30):
     for l,v in self.counter.items():
       printer(id=l,
               value=v,
               label=l,
-              warning=10,
-              critical=30,
+              warning=w,
+              critical=c,
               )
 
   def update_cache(self):
